@@ -52,6 +52,7 @@ pub use ext::SecretVolumeSourceExt;
 pub use ext::ServiceAccountExt;
 pub use ext::ServiceExt;
 pub use ext::SubjectExt;
+pub use ext::ToEnvVar;
 pub use ext::VolumeExt;
 pub use ext::VolumeMountExt;
 
@@ -73,3 +74,18 @@ pub fn typed_ref(
     };
     Some(typed)
 }
+
+pub fn owner_reference(
+    owner: corev1::ObjectReference,
+    is_controller: bool,
+    block_owner_deletion: bool,
+) -> Option<metav1::OwnerReference> {
+    Some(metav1::OwnerReference {
+        block_owner_deletion: Some(block_owner_deletion),
+        controller: Some(is_controller),
+        api_version: owner.api_version?,
+        kind: owner.kind?,
+        name: owner.name?,
+        uid: owner.uid?,
+    })
+}
